# This is only test file for snippets expansion
# Press TAB after each word to expand the snippet
BUILD
DEMOLISH
after
around
augment
before
class
classtype
coerce
excludes
ext
has
hasl
meth
override
requires
role
script
subtype
type
with